@@ -15,7 +15,6 @@ import itertools
 import os
 import re
 
-import pkg_resources
 import six
 
 from oslo_config import cfg
@@ -28,15 +27,6 @@ from ceilometer.pipeline import sample as endpoint
 from ceilometer import sample as sample_util
 
 OPTS = [
-    cfg.StrOpt('meter_definitions_cfg_file',
-               deprecated_for_removal=True,
-               help="Configuration file for defining meter "
-                    "notifications. This option is deprecated "
-                    "and use meter_definitions_dirs to "
-                    "configure meter notification file. Meter "
-                    "definitions configuration file will be sought "
-                    "according to the parameter."
-               ),
     cfg.MultiStrOpt('meter_definitions_dirs',
                     default=["/etc/ceilometer/meters.d",
                              os.path.abspath(
@@ -153,7 +143,7 @@ class MeterDefinition(object):
             nb_samples = len(sample['name'])
             # skip if no meters in payload
             if nb_samples <= 0:
-                raise StopIteration
+                return
 
             attributes = self.SAMPLE_ATTRIBUTES + ["message", "metadata"]
 
@@ -172,7 +162,7 @@ class MeterDefinition(object):
                                 '"%(name)s" field instead of %(total)d.' %
                                 dict(name=name, nb=nb,
                                      total=nb_samples))
-                    raise StopIteration
+                    return
 
             # NOTE(sileht): Transform the sample with multiple values per
             # attribute into multiple samples with one value per attribute.
@@ -200,11 +190,6 @@ class ProcessMeterNotifications(endpoint.SampleEndpoint):
             for filepath in sorted(glob.glob(os.path.join(dir, "*.yaml"))):
                 if filepath is not None:
                     mfs.append(filepath)
-        if self.conf.meter.meter_definitions_cfg_file is not None:
-            mfs.append(
-                pkg_resources.resource_filename(
-                    self.conf.meter.meter_definitions_cfg_file)
-            )
         for mf in mfs:
             meters_cfg = declarative.load_definitions(
                 self.conf, {}, mf)
