@@ -40,6 +40,12 @@ CREDENTIAL_OPTS = [
                help='Secret key for Radosgw Admin.')
 ]
 
+CLIENT_OPTS = [
+    cfg.BoolOpt('implicit_tenants',
+                default=False,
+                help='Whether RGW uses implicit tenants or not.'),
+]
+
 
 class _Base(plugin_base.PollsterBase):
     METHOD = 'bucket'
@@ -49,6 +55,7 @@ class _Base(plugin_base.PollsterBase):
         super(_Base, self).__init__(conf)
         self.access_key = self.conf.rgw_admin_credentials.access_key
         self.secret = self.conf.rgw_admin_credentials.secret_key
+        self.implicit_tenants = self.conf.rgw_client.implicit_tenants
 
     @property
     def default_discovery(self):
@@ -85,13 +92,14 @@ class _Base(plugin_base.PollsterBase):
     def _get_account_info(self, ksclient, tenants):
         endpoint = self._get_endpoint(self.conf, ksclient)
         if not endpoint:
-            raise StopIteration()
+            return
 
         try:
             from ceilometer.objectstore import rgw_client as c_rgw_client
             rgw_client = c_rgw_client.RGWAdminClient(endpoint,
                                                      self.access_key,
-                                                     self.secret)
+                                                     self.secret,
+                                                     self.implicit_tenants)
         except ImportError:
             raise plugin_base.PollsterPermanentError(tenants)
 
@@ -126,16 +134,16 @@ class ContainersSizePollster(_Base):
         for tenant, bucket_info in self._iter_accounts(manager.keystone,
                                                        cache, resources):
             for it in bucket_info['buckets']:
-                    yield sample.Sample(
-                        name='radosgw.containers.objects.size',
-                        type=sample.TYPE_GAUGE,
-                        volume=int(it.size * 1024),
-                        unit='B',
-                        user_id=None,
-                        project_id=tenant,
-                        resource_id=tenant + '/' + it.name,
-                        resource_metadata=None,
-                    )
+                yield sample.Sample(
+                    name='radosgw.containers.objects.size',
+                    type=sample.TYPE_GAUGE,
+                    volume=int(it.size * 1024),
+                    unit='B',
+                    user_id=None,
+                    project_id=tenant,
+                    resource_id=tenant + '/' + it.name,
+                    resource_metadata=None,
+                )
 
 
 class ObjectsSizePollster(_Base):
