@@ -16,7 +16,8 @@
 Tests for VMware vSphere inspector.
 """
 
-import mock
+from unittest import mock
+
 from oslo_vmware import api
 from oslotest import base
 
@@ -91,7 +92,7 @@ class TestVsphereInspection(base.BaseTestCase):
         test_vm_mobj = mock.MagicMock()
         test_vm_mobj.value = "vm-21"
         fake_perf_counter_id = 'fake_perf_counter_id'
-        fake_cpu_util_value = 60
+        fake_cpu_util_value = 60.0
 
         self._inspector._get_vm_mobj_not_power_off_or_raise = mock.MagicMock()
         self._inspector._get_vm_mobj_not_power_off_or_raise.return_value = (
@@ -102,7 +103,7 @@ class TestVsphereInspection(base.BaseTestCase):
         (ops_mock.query_vm_aggregate_stats.
          return_value) = fake_cpu_util_value * 100
         stats = self._inspector.inspect_instance(mock.MagicMock(), None)
-        self.assertEqual(60, stats.cpu_util)
+        self.assertEqual(60.0, stats.cpu_util)
 
     def test_inspect_vnic_rates(self):
 
