@@ -13,8 +13,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import abc
+from unittest import mock
 
-import mock
 from oslotest import base
 import six
 from six.moves.urllib import parse as url_parse
@@ -132,6 +132,23 @@ class TestOpenDayLightDriverSpecial(_Base):
     active_hosts_data = {"hostConfig": []}
     inactive_hosts_data = {"hostConfig": []}
 
+    def test_dict_to_kv(self):
+        data = {'a': 'A',
+                'b': 'B',
+                'nested': {'a': 'A',
+                           'b': 'B',
+                           },
+                'nested2': [{'c': 'A'}, {'c': 'B'}]
+                }
+        pairs = list(self.driver.dict_to_keyval(data))
+        self.assertEqual([('a', 'A'),
+                          ('b', 'B'),
+                         ('nested.a', 'A'),
+                         ('nested.b', 'B'),
+                         ('nested2[0].c', 'A'),
+                         ('nested2[1].c', 'B')],
+                         sorted(pairs, key=lambda x: x[0]))
+
     def test_not_implemented_meter(self):
         sample_data = self.driver.get_sample_data('egg',
                                                   self.fake_odl_url,
