@@ -12,13 +12,11 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-"""Tests for ceilometer/publisher/udp.py
-"""
+"""Tests for ceilometer/publisher/udp.py"""
 
 import datetime
-import socket
+from unittest import mock
 
-import mock
 import msgpack
 from oslo_utils import netutils
 from oslotest import base
@@ -113,42 +111,6 @@ class TestUDPPublisher(base.BaseTestCase):
         self.CONF = service.prepare_service([], [])
         self.CONF.publisher.telemetry_secret = 'not-so-secret'
 
-    def _check_udp_socket(self, url, expected_addr_family):
-        with mock.patch.object(socket, 'socket') as mock_socket:
-            udp.UDPPublisher(self.CONF, netutils.urlsplit(url))
-            mock_socket.assert_called_with(expected_addr_family,
-                                           socket.SOCK_DGRAM)
-
-    def test_publisher_udp_socket_ipv4(self):
-        self._check_udp_socket('udp://127.0.0.1:4952',
-                               socket.AF_INET)
-
-    def test_publisher_udp_socket_ipv6(self):
-        self._check_udp_socket('udp://[::1]:4952',
-                               socket.AF_INET6)
-
-    def test_publisher_udp_socket_ipv4_hostname(self):
-        host = "ipv4.google.com"
-        try:
-            socket.getaddrinfo(host, None,
-                               socket.AF_INET,
-                               socket.SOCK_DGRAM)
-        except socket.gaierror:
-            self.skipTest("cannot resolve not running test")
-        url = "udp://"+host+":4952"
-        self._check_udp_socket(url, socket.AF_INET)
-
-    def test_publisher_udp_socket_ipv6_hostname(self):
-        host = "ipv6.google.com"
-        try:
-            socket.getaddrinfo(host, None,
-                               socket.AF_INET6,
-                               socket.SOCK_DGRAM)
-        except socket.gaierror:
-            self.skipTest("cannot resolve not running test")
-        url = "udp://"+host+":4952"
-        self._check_udp_socket(url, socket.AF_INET6)
-
     def test_published(self):
         self.data_sent = []
         with mock.patch('socket.socket',
